==> tuia-ecb-center-api-1.0.1.2-20190711.030251-4-sources.jar: cn/com/duiba/tuia/ecb/center/dto/video/VideoDto.java <==
package cn.com.duiba.tuia.ecb.center.dto.video;

import java.io.Serializable;
import java.util.Date;

/**
 * 激励视频dto
 * Created by xuefeng on 2019/6/10.
 */
public class VideoDto implements Serializable {

    private String id;

    //0:本地视频 1：推啊视频
    private Integer videoSource;

    //标题
    private String title;

    //icon
    private String iconUrl;

    //slogen标语
    private String slogen;

    //视频地址
    private String videoUrl;

    //视频地址 压缩
    private String videoUrl2;

    //视频时长
    private Integer videoLength;

    //展示关闭按钮时长
    private Integer videoCloseLength;

    //下载包地址
    private String downPackage;

    //下载地址
    private String downUrl;

    private String descri;

    //落地页
    private String landUrl;

    //0:横屏 1:竖屏
    private Integer vStyle;

    //弹幕
    private String bilibilis;

    private Date gmtCreate;

    //吸底按钮文案
    private String bottomDesc;

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public Integer getVideoSource() {
        return videoSource;
    }

    public void setVideoSource(Integer videoSource) {
        this.videoSource = videoSource;
    }

    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public String getIconUrl() {
        return iconUrl;
    }

    public void setIconUrl(String iconUrl) {
        this.iconUrl = iconUrl;
    }

    public String getSlogen() {
        return slogen;
    }

    public void setSlogen(String slogen) {
        this.slogen = slogen;
    }

    public String getVideoUrl() {
        return videoUrl;
    }

    public void setVideoUrl(String videoUrl) {
        this.videoUrl = videoUrl;
    }

    public String getVideoUrl2() {
        return videoUrl2;
    }

    public void setVideoUrl2(String videoUrl2) {
        this.videoUrl2 = videoUrl2;
    }

    public Integer getVideoLength() {
        return videoLength;
    }

    public void setVideoLength(Integer videoLength) {
        this.videoLength = videoLength;
    }

    public Integer getVideoCloseLength() {
        return videoCloseLength;
    }

    public void setVideoCloseLength(Integer videoCloseLength) {
        this.videoCloseLength = videoCloseLength;
    }

    public String getDownPackage() {
        return downPackage;
    }

    public void setDownPackage(String downPackage) {
        this.downPackage = downPackage;
    }

    public String getDownUrl() {
        return downUrl;
    }

    public void setDownUrl(String downUrl) {
        this.downUrl = downUrl;
    }

    public String getDescri() {
        return descri;
    }

    public void setDescri(String descri) {
        this.descri = descri;
    }

    public String getLandUrl() {
        return landUrl;
    }

    public void setLandUrl(String landUrl) {
        this.landUrl = landUrl;
    }

    public Integer getvStyle() {
        return vStyle;
    }

    public void setvStyle(Integer vStyle) {
        this.vStyle = vStyle;
    }

    public String getBilibilis() {
        return bilibilis;
    }

    public void setBilibilis(String bilibilis) {
        this.bilibilis = bilibilis;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public String getBottomDesc() {
        return bottomDesc;
    }

    public void setBottomDesc(String bottomDesc) {
        this.bottomDesc = bottomDesc;
    }
}

==> tuia-ecb-center-api-1.0.1.9-20190802.060741-5-sources.jar: cn/com/duiba/tuia/ecb/center/dto/video/VideoDto.java <==
package cn.com.duiba.tuia.ecb.center.dto.video;

import cn.com.duiba.tuia.ecb.center.cpd.dto.EmbedUrlDto;

import java.io.Serializable;
import java.util.Date;

/**
 * 激励视频dto
 * Created by xuefeng on 2019/6/10.
 */
public class VideoDto implements Serializable {

    private String id;

    //0:本地视频 1：推啊视频
    private Integer videoSource;

    //标题
    private String title;

    //icon
    private String iconUrl;

    //slogen标语
    private String slogen;

    //视频地址
    private String videoUrl;

    //视频地址 压缩
    private String videoUrl2;

    //视频时长
    private Integer videoLength;

    //展示关闭按钮时长
    private Integer videoCloseLength;

    //下载包地址
    private String downPackage;

    //下载地址
    private String downUrl;

    private String descri;

    //落地页
    private String landUrl;

    //0:横屏 1:竖屏
    private Integer vStyle;

    //弹幕
    private String bilibilis;

    private Date gmtCreate;

    //吸底按钮文案
    private String bottomDesc;

    //广告计划id
    private Long advertId;

    //上报信息
    private Long packageId;

    //上报信息
    private String effectiveMainType;

    //广告素材
    private String adImg;

    //上架状态 0:待上架 1:已上架
    private Integer vStatus;

    //0:新素材，需要额外曝光 1:旧素材
    private Integer vNew;

    //视频展示算法 0:随机 1:按推荐(转化率) 2:新素材 3:按单价
    private Integer alg = 0;

    //urlScheme
    private String urlScheme;

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public Integer getVideoSource() {
        return videoSource;
    }

    public void setVideoSource(Integer videoSource) {
        this.videoSource = videoSource;
    }

    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public String getIconUrl() {
        return iconUrl;
    }

    public void setIconUrl(String iconUrl) {
        this.iconUrl = iconUrl;
    }

    public String getSlogen() {
        return slogen;
    }

    public void setSlogen(String slogen) {
        this.slogen = slogen;
    }

    public String getVideoUrl() {
        return videoUrl;
    }

    public void setVideoUrl(String videoUrl) {
        this.videoUrl = videoUrl;
    }

    public String getVideoUrl2() {
        return videoUrl2;
    }

    public void setVideoUrl2(String videoUrl2) {
        this.videoUrl2 = videoUrl2;
    }

    public Integer getVideoLength() {
        return videoLength;
    }

    public void setVideoLength(Integer videoLength) {
        this.videoLength = videoLength;
    }

    public Integer getVideoCloseLength() {
        return videoCloseLength;
    }

    public void setVideoCloseLength(Integer videoCloseLength) {
        this.videoCloseLength = videoCloseLength;
    }

    public String getDownPackage() {
        return downPackage;
    }

    public void setDownPackage(String downPackage) {
        this.downPackage = downPackage;
    }

    public String getDownUrl() {
        return downUrl;
    }

    public void setDownUrl(String downUrl) {
        this.downUrl = downUrl;
    }

    public String getDescri() {
        return descri;
    }

    public void setDescri(String descri) {
        this.descri = descri;
    }

    public String getLandUrl() {
        return landUrl;
    }

    public void setLandUrl(String landUrl) {
        this.landUrl = landUrl;
    }

    public Integer getvStyle() {
        return vStyle;
    }

    public void setvStyle(Integer vStyle) {
        this.vStyle = vStyle;
    }

    public String getBilibilis() {
        return bilibilis;
    }

    public void setBilibilis(String bilibilis) {
        this.bilibilis = bilibilis;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public String getBottomDesc() {
        return bottomDesc;
    }

    public void setBottomDesc(String bottomDesc) {
        this.bottomDesc = bottomDesc;
    }

    public Long getAdvertId() {
        return advertId;
    }

    public void setAdvertId(Long advertId) {
        this.advertId = advertId;
    }

    public Long getPackageId() {
        return packageId;
    }

    public void setPackageId(Long packageId) {
        this.packageId = packageId;
    }

    public String getEffectiveMainType() {
        return effectiveMainType;
    }

    public void setEffectiveMainType(String effectiveMainType) {
        this.effectiveMainType = effectiveMainType;
    }

    public String getAdImg() {
        return adImg;
    }

    public void setAdImg(String adImg) {
        this.adImg = adImg;
    }

    public Integer getvStatus() {
        return vStatus;
    }

    public void setvStatus(Integer vStatus) {
        this.vStatus = vStatus;
    }

    public Integer getvNew() {
        return vNew;
    }

    public void setvNew(Integer vNew) {
        this.vNew = vNew;
    }

    public Integer getAlg() {
        return alg;
    }

    public void setAlg(Integer alg) {
        this.alg = alg;
    }

    public String getUrlScheme() {
        return urlScheme;
    }

    public void setUrlScheme(String urlScheme) {
        this.urlScheme = urlScheme;
    }
}
